/*******************************************************************************
This do file is to produce textbook figures in Undergraduate Econometrics 
textbook of Professor Diebold. 

Author: Theodore Caputi, Donato Onorato, JoonYup Park, Sarah Winton
Date: 3/30/2017
Project: Undergraduate Econometrics Textbook (Wages)
Contact: joonyup@wharton.upenn.edu

Source: 

Note: 

Updates:
	-5/20/2017 by JoonYup:
	Added LAD, 10pct, 90pct quantile regressions for LNWAGE ~ c, EDUC 
	
	-5/21/2017 by Theodore:
	Added combined graph for OLS, LAD, 10pct, 90pct loss functions
	
	-5/27/2017 by JoonYup:
	Added Leave-one-out plot and leverage plot
********************************************************************************/

clear all
set more off
set graphics off //comment this out if you want to see the graph as you go

*** Install packages
cap ssc install outreg2


*** Set working directory
global userdir "" // <- input your working directory here
global userdir "C:\Users\fdiebold\Dropbox\Econometrics\MasterDataAndCode_HOT\Code_Stata\Stata_Wage"
global logs "${userdir}/logs"
global tabfig "${userdir}/tabfig"

*** Input file
global wagedata "${userdir}/DataWages.csv"

*** Output file

/* Start logging */
cap log close
log using "${logs}\CodeStataWages_`c(current_date)'.txt", replace text


insheet using "${wagedata}", comma clear

/*********************************************************************
 Create variables needed for graphing (fitted values, residuals...)
*********************************************************************/
gen educ2 = educ^2
gen exper2 = exper^2	
gen educXexper = educ * exper
gen femaleXunion = female * union
gen femaleXnonwhite = female * nonwhite
gen unionXnonwhite = union * nonwhite

reg lnwage educ exper
predict lnwage_fit1

reg lnwage educ exper female nonwhite union
predict lnwage_fit2

reg lnwage educ exper exper2 educXexper female union nonwhite
predict resid, residual
gen resid2 = resid^2

/***********************
 Produce figures
************************/
*Histogram of wage 
hist wage, freq bin(28) title("") xtitle("Wage") ///
	name(hist_wage, replace) 
graph export "${tabfig}/hist_wage.pdf", as(pdf) replace

*Histogram of lnwage
hist lnwage, freq bin(40) title("") xtitle("ln(Wage)") ///
	name(hist_lnwage, replace)
graph export "${tabfig}/hist_lnwage.pdf", as(pdf) replace

*Histogram for educ
hist educ, freq bin(40)	title("") xtitle("Education") ///
	name(hist_educ, replace)
graph export "${tabfig}/hist_educ.pdf", as(pdf) replace

*Histogram for exper
hist exper, freq bin(40) title("") xtitle("Experience") ///
	name(hist_exper, replace)
graph export "${tabfig}/hist_exper.pdf", as(pdf) replace

*Histogram for nonwhite
gen countvar = 1
graph bar (sum) countvar, over(nonwhite) ytitle("Frequency") ///
	name(hist_nonwhite, replace)
graph export "${tabfig}/hist_nonwhite.pdf", as(pdf) replace
	
*Histogram for union
graph bar (sum) countvar, over(union) ytitle("Frequency") ///
	name(hist_union, replace)
graph export "${tabfig}/hist_union.pdf", as(pdf) replace
	
*Kernel density plot for wage
kdensity wage, normal title("") xtitle("Wage") note("") ///
	name(kden_wage, replace)
graph export "${tabfig}/kden_wage.pdf", as(pdf) replace
	
*Kernel density plot for lnwage
kdensity lnwage, normal title("") xtitle("ln(Wage)") note("") ///
	name(kden_lnwage, replace)
graph export "${tabfig}/kden_lnwage.pdf", as(pdf) replace
	
*QQ-plot for wage
qnorm wage
graph export "${tabfig}/qqplot_wage.pdf", as(pdf) replace

*QQ-plot for lnwage	
qnorm lnwage
graph export "${tabfig}/qqnorm_lnwage.pdf", as(pdf) replace

*Plot (educ, lnwage)
graph twoway scatter lnwage educ, ///
	name(plot_educ_lnwage, replace)
graph export "${tabfig}/plot_educ_lnwage.pdf", as(pdf) replace
	
*Plot (educ, lnwage) and a fitted line
graph twoway ///
	scatter lnwage educ || ///
	lfit lnwage educ, ytitle("LNWAGE") legend(off) ///
	name(plot_educ_lnwage_fitted, replace)
graph export "${tabfig}/plot_educ_lnwage_fitted.pdf", as(pdf) replace

*Plot (lnwage, lnwage_fit1 )
graph twoway scatter lnwage lnwage_fit1, ///
	name(plot_lnwage_lnwagefit1, replace)	
graph export "${tabfig}/plot_lnwage_lnwagefit1.pdf", as(pdf) replace

*Plot (lnwage, lnwage_fit2)
graph twoway scatter lnwage lnwage_fit2, ///
	name(plot_lnwage_lnwagefit2, replace)
graph export "${tabfig}/plot_lnwage_lnwagefit2.pdf", as(pdf) replace

*Plot (resid2, educ)	
graph twoway scatter resid2 educ, ytitle("RESID2") ///
	name(plot_resid2_educ, replace)
graph export "${tabfig}/plot_resid2_educ.pdf", as(pdf) replace
	
	
/* Figure 2.5 */
*Histograms for wage and lnwage
*Kernel density plot for wage and lnwage
*QQ-plot for wage and lnwage

/* Figure 4.1 */
*Histogram for lnwage, educ, and exper

/* Figure 4.2 */
*Plot (educ, lnwage) 

/* Figure 4.3 */
*Plot (educ, lnwage) and a fitted line

/* Figure 4.4 */
*Regress lnwage on educ and exper
reg lnwage educ exper

/* Figure 4.5 */
*Plot (lnwage_fit1, lnwage)
	
/* Figure 4.6 */	
	
/* Figure 5.1 */
*Histograms for educ, exper, nonwhite, and union

/* Figure 5.2 */
*Regress lnwage on educ and exper
reg lnwage educ exper

/* Figure 5.3 */	
*Regress lnwage on educ, exper, female, nonwhite, and union
reg lnwage educ exper female nonwhite union
	
/* Figure 5.4 */	
*Generate predicted values for lnwage 
// predict lnwage_fit3 // this used to be lnwage_fit2

*Plot (lnwage_fit2, lnwage)
graph twoway ///
	scatter lnwage_fit2 lnwage // this used to be lnwage_fit2
	
/* Figure 5.5 */


/* Figure 7.1 */
*Regress lnwage on educ, exper, female, nonwhite, and union
reg lnwage educ exper female nonwhite union
	
/* Figure 7.2 */
// gen educ2 = educ^2
// gen exper2 = exper^2	
// gen educXexper = educ * exper
	
*Regress lnwage on educ, educ^2, exper, exper^2, educXexper, female, union, and nonwhite
reg lnwage educ educ2 exper exper2 educXexper female union nonwhite	
	

/* Figure 7.3 */
// gen femaleXunion = female * union
// gen femaleXnonwhite = female * nonwhite
// gen unionXnonwhite = union * nonwhite

*Regress lnwage on educ, exper, female, union, nonwhite, femaleXunion, femaleXnonwhite, and unionXnonwhite
reg lnwage educ exper female union nonwhite femaleXunion femaleXnonwhite unionXnonwhite

/* Figure 7.4 */
*Regress lnwage on educ, educ^2, exper, exper^2, educXexper, female, union, nonwhite, femaleXunion, femaleXnonwhite, unionXnonwhite
reg	lnwage educ educ2 exper exper2 educXexper female union nonwhite femaleXunion femaleXnonwhite unionXnonwhite

/* Figure 7.5 */	


/* Figure 9.X */
*Regress lnwage on educ, exper, exper^2, educXexper, female, union, and nonwhite
reg lnwage educ exper exper2 educXexper female union nonwhite

*Generate residuals and plot (educ, resid^2)
// predict resid, residual
// gen resid2 = resid^2

graph twoway ///
	scatter resid2 educ

/* LNWAGE ~ c, EDUC: OLS regression */
reg lnwage educ	
predict lnwage_fitOLS

*Store regression coefficients in a macro to put on the graph as text
mat B = e(b)
local educ_coef = round(B[1,1],0.001)
local intercept = round(B[1,2],0.001)

graph twoway ///
	scatter lnwage educ || ///
	line lnwage_fitOLS educ, legend(off) title("LNWAGE ~ c, EDUC (OLS)") ytitle("LNWAGE") text(0 10 "LNWAGE = `intercept' + `educ_coef' EDUC") ///
	name(plot_educ_lnwage_OLS, replace)
graph export "${tabfig}/plot_educ_lnwage_OLS.pdf", as(pdf) replace


/* LNWAGE ~ c, EDUC: LAD regression */
qreg lnwage educ, quantile(.5)
predict lnwage_fitLAD 

*Store regression coefficients in a macro to put on the graph as text
mat B = e(b)
local educ_coef = round(B[1,1],0.001)
local intercept = round(B[1,2],0.001)

graph twoway ///
	scatter lnwage educ || ///
	line lnwage_fitLAD educ, legend(off) title("LNWAGE ~ c, EDUC (LAD)") ytitle("LNWAGE") text(0 10 "LNWAGE = `intercept' + `educ_coef' EDUC") ///
	name(plot_educ_lnwage_LAD, replace)
graph export "${tabfig}/plot_educ_lnwage_LAD.pdf", as(pdf) replace

/* LNWAGE ~ c, EDUC: Quantile regression--10% */	
qreg lnwage educ, quantile(.1)
predict lnwage_fit10pct

*Store regression coefficients in a macro to put on the graph as text
mat B = e(b)
local educ_coef = round(B[1,1],0.001)
local intercept = round(B[1,2],0.001)

graph twoway ///	
	scatter lnwage educ || ///
	line lnwage_fit10pct educ, legend(off) title("LNWAGE ~ c, EDUC (10-percentile)") ytitle("LNWAGE") text(0 10 "LNWAGE = `intercept' + `educ_coef' EDUC") ///
	name(plot_educ_lnwage_10pct, replace)
graph export "${tabfig}/plot_educ_lnwage_10pct.pdf", as(pdf) replace
	
/* LNWAGE ~ c, EDUC: Quantile regression--90% */	
qreg lnwage educ, quantile(.9)
predict lnwage_fit90pct

*Store regression coefficients in a macro to put on the graph as text
mat B = e(b)
local educ_coef = round(B[1,1],0.001)
local intercept = round(B[1,2],0.001)

graph twoway ///
	scatter lnwage educ || ///
	line lnwage_fit90pct educ, legend(off) title("LNWAGE ~ c, EDUC (90-percentile)") ytitle("LNWAGE") text(0 10 "LNWAGE = `intercept' + `educ_coef' EDUC") ///
	name(plot_educ_lnwage_90pct, replace)
graph export "${tabfig}/plot_educ_lnwage_90pct.pdf", as(pdf) replace

*Combine OLS, LAD, 10pct, 90pct graphs into one pdf
graph combine plot_educ_lnwage_OLS plot_educ_lnwage_LAD plot_educ_lnwage_10pct plot_educ_lnwage_90pct, rows(2)
graph export "${tabfig}/plot_educ_lnwage_combined.pdf", as(pdf) replace	

*** Generate output XLS (Excel) file for presentation 
qui reg lnwage educ exper 
outreg2 using "${tabfig}\reg1.xls", title(LNWAGE = f(EDUC, EXPER)) sideway replace label(insert) stats(coef se tstat pval skewness kurtosis) // this will require some beautification 


*** Multiple lines in one scatter

graph twoway ///
	scatter lnwage educ || ///
	line lnwage_fitOLS educ || ///
	line lnwage_fitLAD educ || ///
	line lnwage_fit90pct educ || ///
	line lnwage_fit10pct educ || ///
	, ///
	legend(order(1 "Least Squares" 2 "LAD" 3 "90pct Quantile Reg." 4 "10pct Quantile Reg.")) ///
	title("LNWAGE ~ c, EDUC") ytitle("LNWAGE") text(0 10 "LNWAGE = `intercept' + `educ_coef' EDUC") ///
	name(combined_plot_educ_lnwage, replace)
graph export "${tabfig}/combined_plot_educ_lnwage.pdf", as(pdf) replace

/* Leave-one-out plot for LNWAGE ~ EDUC */ 
reg lnwage educ
mat b = e(b)
local b_orig = b[1,1]

qui count
local N = `r(N)'

gen b_loo_coef_change =.

qui forval i=1/`N' {

	gen byte select = 1
	replace select = 0 in `i'
	
	reg lnwage educ if select == 1
	mat b = e(b)
	local b_loo = b[1,1]
	
	replace b_loo_coef_change = `b_loo' - `b_orig' in `i'
	
	drop select
}

gen index = _n
graph twoway ///
	scatter b_loo_coef_change index, title("Leave-One-Out Plot") xtitle("Leave t out") ytitle("Change in Coefficient") msize(small)
graph export "${tabfig}/plot_leave_one_out.pdf", as(pdf) replace


/* Leverage plot for LNWAGE ~ EDUC */
reg lnwage educ
lvr2plot, msize(small)
graph export "${tabfig}/plot_leverage.pdf", as(pdf) replace


/* Simple plot of Index X EDUC */
graph twoway ///
	scatter educ index, title("EDUC by Index") xtitle("t") ytitle("EDUC")
graph export "${tabfig}/plot_index_educ.pdf", as(pdf) replace


*** Close the log
cap log close	

